utils::globalVariables(c("COMID", "HTML", "ID", "acres", "characteristic_id",
                         "characteristic_value", "chars", "data", "featureid",
                         "group_by", "mi", "req", "sessionEnded", "setProgress",
                         "tags", "withProgress",".", "rowid")
)

